// AUTO-GENERATED BY UpdateGenVersion.bat a027cb334da0294b33163557d3f832ae9224ce53
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "a027cb334da0294b33163557d3f832ae9224ce53";
